@@ -5,12 +5,12 @@ from uiutil import BaseFrame
 from uiutil.tk_names import W, DISABLED, NORMAL, EW, HORIZONTAL, NSEW, IntVar, StringVar, BooleanVar
 from fdutil.list_tools import filter_list
 from networkutil.gui.pickler_frame import RequestPicklerWindow
+from ..support import make_modifier_tooltip_from_docstring
 from ...config.constants import ModifierConstant, ScenarioConstant
 from ...config.intercept import InterceptConfig
 from ...config.intercept_handlers import Handlers
 from ...config.intercept_scenarios import Scenarios
 from ...intercept import InterceptModifiers
-from ...intercept.handlers.support import make_modifier_tooltip_from_docstring
 
 logging = logging_helper.setup_logging()
 
@@ -131,7 +131,6 @@ class AddEditScenarioFrame(BaseFrame):
                        padx=5,
                        pady=5)
 
-
         self.__add_config_row_button = self.button(state=NORMAL,
                                                    text=u'+',
                                                    width=5,
