@@ -24,7 +24,7 @@ class ScenariosConfigWindow(ChildWindow):
         super(ScenariosConfigWindow, self).__init__(*args,
                                                     **kwargs)
 
-    def _setup(self):
+    def _draw_widgets(self):
         self.title(u"Intercept Scenarios Config")
 
         self.config = ScenariosConfigFrame(parent=self._main_frame,
