@@ -18,13 +18,13 @@ HOSTNAME_INDEX = 2
 
 
 def modify(uri,
-           parameters):
+           modifier):
 
     parts = uri.split(u'/')
-    if parameters.passes_filter(parts[HOSTNAME_INDEX]):
-        new_endpoint = (parameters.override
-                        if parameters.override
-                        else parameters.params)
+    if modifier.passes_filter(parts[HOSTNAME_INDEX]):
+        new_endpoint = (modifier.override
+                        if modifier.override
+                        else modifier.params)
         parts[HOSTNAME_INDEX] = new_endpoint
 
         uri = u'/'.join(parts)
