@@ -16,8 +16,8 @@ logging = logging_helper.setup_logging()
 
 
 def modify(uri,
-           parameters):
-    if parameters.passes_filter(uri):
-        uri = parameters.params
+           modifier):
+    if modifier.passes_filter(uri):
+        uri = modifier.params
 
     return uri
